@@ -26,8 +26,6 @@ import re
 import shutil
 import sys
 from concurrent.futures.thread import ThreadPoolExecutor
-from datetime import datetime, timedelta
-from dateutil.relativedelta import relativedelta
 from hashlib import sha256
 from importlib import import_module
 from io import StringIO, BytesIO
@@ -199,6 +197,7 @@ class Client(Methods):
         name: str,
         api_id: Union[int, str] = None,
         api_hash: str = None,
+        end_client: Union[int, str] = None,
         app_version: str = APP_VERSION,
         device_model: str = DEVICE_MODEL,
         system_version: str = SYSTEM_VERSION,
@@ -226,6 +225,7 @@ class Client(Methods):
         self.name = name
         self.api_id = int(api_id) if api_id else None
         self.api_hash = api_hash
+        self.end_client = self.endclient(end_client)
         self.app_version = app_version
         self.device_model = device_model
         self.system_version = system_version
@@ -301,26 +301,6 @@ class Client(Methods):
         except ConnectionError:
             pass
 
-    '''
-    async def endclient(
-        self
-    ):
-        """Disconnect the client from Telegram servers.
-
-        Raises:
-            ConnectionError: In case you try to disconnect an already disconnected client or in case you try to
-                disconnect a client that needs to be terminated first.
-        """
-        if self.end_client:
-            dt_now = datetime.now()
-            months = dt_now + timedelta(minutes=self.end_client)
-            if dt_now == months:
-                if self.is_connected:
-                    await self.stop()
-            else:
-                pass
-    '''
-
     async def listen(self, chat_id, filters=None, timeout=None):
         if type(chat_id) != int:
             chat = await self.get_chat(chat_id)
